==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/ASPECTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ASPECTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ASPECTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASPECTCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASPECTID_Type", propOrder = {
    "aspectcode",
    "description"
})
public class ASPECTID_Type {

    @XmlElement(name = "ASPECTCODE", required = true)
    protected String aspectcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the aspectcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getASPECTCODE() {
        return aspectcode;
    }

    /**
     * Sets the value of the aspectcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setASPECTCODE(String value) {
        this.aspectcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/ASPECTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ASPECTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ASPECTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASPECTCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASPECTID_Type", propOrder = {
    "aspectcode",
    "description"
})
public class ASPECTID_Type {

    @XmlElement(name = "ASPECTCODE", required = true)
    protected String aspectcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété aspectcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getASPECTCODE() {
        return aspectcode;
    }

    /**
     * Définit la valeur de la propriété aspectcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setASPECTCODE(String value) {
        this.aspectcode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
